@@ -180,12 +180,17 @@ void MainWindow::createMenu() {
     m_pOrientationSelector = new PickSelectorAction(this);
     m_pOrientationSelector->setText("Orientation");
     m_pOrientationSelector->items() << "Auto" << "Landscape" << "Portrait";
+    m_pOrientationSelector->setSelectedIndex(
+        isAutoRotate() ? 0 :
+        (testAttribute(Qt::WA_Maemo5LandscapeOrientation) || !testAttribute(Qt::WA_Maemo5PortraitOrientation) ? 1 : 2)
+    );
     connect(m_pOrientationSelector, SIGNAL(selectionChanged(int)), this, SLOT(orientation_selectionChanged(int)));
     menuBar()->addAction(m_pOrientationSelector);
 
     m_pUserAgentSelector = new PickSelectorAction(this);
     m_pUserAgentSelector->setText("User Agent");
     m_pUserAgentSelector->items() << "iPhone" << "Default";
+    m_pUserAgentSelector->setSelectedIndex(m_webPage.isIphoneUserAgent()?0:1);
     connect(m_pUserAgentSelector, SIGNAL(selectionChanged(int)), this, SLOT(userAgent_selectionChanged(int)));
     menuBar()->addAction(m_pUserAgentSelector);
 #else
@@ -344,6 +349,7 @@ void MainWindow::loadSettings() {
         //...
     }
 
+    Q_ASSERT(m_pBookmarks);
     (*m_pBookmarks) = settings.value("bookmarks").value< QList<Bookmark> >();
     setFullScreen(settings.value("fullScreen", false).toBool());
     setUserAgent(settings.value("iphoneUserAgent", true).toBool());
@@ -383,9 +389,11 @@ void MainWindow::saveSettings() {
     settings.setValue("iphoneUserAgent", m_webPage.isIphoneUserAgent());
 
 #ifdef Q_WS_MAEMO_5
+    Q_ASSERT(m_pOrientationSelector);
     settings.setValue("orientation", m_pOrientationSelector->selectedIndex());
 #endif
 
+    Q_ASSERT(m_pBookmarks);
     QVariant bookmarks;
     bookmarks.setValue(*m_pBookmarks);
     settings.setValue("bookmarks", bookmarks);
@@ -427,17 +435,24 @@ void MainWindow::visitUrl(QString url) {
 
     if ( url.isNull() || url.isEmpty() ) return;
 
-    if ( m_isUsingGraphicsView )
+    if ( m_isUsingGraphicsView ) {
+        Q_ASSERT(m_pGWebView);
         m_pGWebView->load(QUrl::fromUserInput(url));
-    else
+    } else {
+        Q_ASSERT(m_pWebView);
         m_pWebView->load(QUrl::fromUserInput(url));
+    }
 }
 
 void MainWindow::reload() {
-    if ( m_isUsingGraphicsView )
+    if ( m_isUsingGraphicsView ) {
+        Q_ASSERT(m_pGWebView);
         m_pGWebView->load(m_currentUrl);
-    else
+    } else {
+        Q_ASSERT(m_pWebView);
         m_pWebView->load(m_currentUrl);
+    }
+
     /*
 #ifndef Q_WS_MAEMO_5
     m_pErrorBox->hide();
@@ -512,12 +527,14 @@ void MainWindow::setZoom(qreal zoomFactor) {
     updateTitle();
 
     if ( m_isUsingGraphicsView ) {
+        Q_ASSERT(m_pGWebView && m_pGraphicsView);
         if ( !m_pGWebView ) return;
         m_pGWebView->setZoomFactor(m_zoomFactor);
         m_pGraphicsView->viewportItem()->resizeWebViewToFrame();
         return;
     }
 
+    Q_ASSERT(m_pWebView);
     if ( !m_pWebView ) return;
     m_pWebView->setZoomFactor(m_zoomFactor);
 }
@@ -565,8 +582,7 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
     }
 }
 
-void MainWindow::enableWebkitAutoSize()
-{
+void MainWindow::enableWebkitAutoSize() {
     m_webPage.mainFrame()->evaluateJavaScript("document.body.style.WebkitTextSizeAdjust = 'auto'");
 }
 
@@ -577,6 +593,7 @@ void MainWindow::on_actionHome_triggered() {
 
 void MainWindow::on_actionBookmarks_triggered()
 {
+    Q_ASSERT(m_pBookmarks);
     BookmarksDlg dlg((*m_pBookmarks), this);
 
 #ifdef Q_WS_MAEMO_5
@@ -625,6 +642,7 @@ void MainWindow::on_actionAdd_Bookmark_triggered()
 {
     BookmarkDlg dlg(this);
     dlg.setUrl(m_currentUrl.toString());
+    Q_ASSERT((m_isUsingGraphicsView && !m_pGWebView) || (!m_isUsingGraphicsView  && m_pWebView));
     dlg.setTitle( m_isUsingGraphicsView ? m_pGWebView->title() : m_pWebView->title() );
     dlg.removeBtt()->setVisible(false);
 
@@ -633,6 +651,8 @@ void MainWindow::on_actionAdd_Bookmark_triggered()
     Bookmark mark;
     mark.setTitle(dlg.title());
     mark.setUrl(dlg.url());
+
+    Q_ASSERT(m_pBookmarks);
     m_pBookmarks->append(mark);
 }
 
@@ -663,7 +683,7 @@ void MainWindow::orientationChanged() {
 }
 
 void MainWindow::setLandscape(bool landscape/*=true*/) {
-    m_pOrientationSelector->setSelectedIndex(landscape?1:2);
+    if ( m_pOrientationSelector ) m_pOrientationSelector->setSelectedIndex(landscape?1:2);
 
     if ( landscape ) {
         qDebug() << ">> set Landscape";
